==> huaweicloudsdkcbr-3.1.28-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import models into model package
from huaweicloudsdkcbr.v1.model.add_member_request import AddMemberRequest
from huaweicloudsdkcbr.v1.model.add_member_response import AddMemberResponse
from huaweicloudsdkcbr.v1.model.add_members_req import AddMembersReq
from huaweicloudsdkcbr.v1.model.add_vault_resource_request import AddVaultResourceRequest
from huaweicloudsdkcbr.v1.model.add_vault_resource_response import AddVaultResourceResponse
from huaweicloudsdkcbr.v1.model.associate_vault_policy_request import AssociateVaultPolicyRequest
from huaweicloudsdkcbr.v1.model.associate_vault_policy_response import AssociateVaultPolicyResponse
from huaweicloudsdkcbr.v1.model.backup_extend_info import BackupExtendInfo
from huaweicloudsdkcbr.v1.model.backup_replicate_req import BackupReplicateReq
from huaweicloudsdkcbr.v1.model.backup_replicate_req_body import BackupReplicateReqBody
from huaweicloudsdkcbr.v1.model.backup_replicate_resp_body import BackupReplicateRespBody
from huaweicloudsdkcbr.v1.model.backup_resp import BackupResp
from huaweicloudsdkcbr.v1.model.backup_restore import BackupRestore
from huaweicloudsdkcbr.v1.model.backup_restore_req import BackupRestoreReq
from huaweicloudsdkcbr.v1.model.backup_restore_server_mapping import BackupRestoreServerMapping
from huaweicloudsdkcbr.v1.model.backup_sync import BackupSync
from huaweicloudsdkcbr.v1.model.backup_sync_req import BackupSyncReq
from huaweicloudsdkcbr.v1.model.backup_sync_resp_body import BackupSyncRespBody
from huaweicloudsdkcbr.v1.model.batch_create_and_delete_vault_tags_request import BatchCreateAndDeleteVaultTagsRequest
from huaweicloudsdkcbr.v1.model.batch_create_and_delete_vault_tags_response import BatchCreateAndDeleteVaultTagsResponse
from huaweicloudsdkcbr.v1.model.billbing_create_extra_info import BillbingCreateExtraInfo
from huaweicloudsdkcbr.v1.model.billing import Billing
from huaweicloudsdkcbr.v1.model.billing_create import BillingCreate
from huaweicloudsdkcbr.v1.model.billing_update import BillingUpdate
from huaweicloudsdkcbr.v1.model.bind_rules_tags import BindRulesTags
from huaweicloudsdkcbr.v1.model.bulk_create_and_delete_vault_tags_req import BulkCreateAndDeleteVaultTagsReq
from huaweicloudsdkcbr.v1.model.cbc_order_result import CbcOrderResult
from huaweicloudsdkcbr.v1.model.checkpoint_create import CheckpointCreate
from huaweicloudsdkcbr.v1.model.checkpoint_create_skipped_resource import CheckpointCreateSkippedResource
from huaweicloudsdkcbr.v1.model.checkpoint_extra_info_resp import CheckpointExtraInfoResp
from huaweicloudsdkcbr.v1.model.checkpoint_param import CheckpointParam
from huaweicloudsdkcbr.v1.model.checkpoint_plan_create import CheckpointPlanCreate
from huaweicloudsdkcbr.v1.model.checkpoint_replicate_param import CheckpointReplicateParam
from huaweicloudsdkcbr.v1.model.checkpoint_replicate_req import CheckpointReplicateReq
from huaweicloudsdkcbr.v1.model.checkpoint_replicate_resp_body import CheckpointReplicateRespBody
from huaweicloudsdkcbr.v1.model.checkpoint_replicate_respbackups import CheckpointReplicateRespbackups
from huaweicloudsdkcbr.v1.model.checkpoint_resource_resp import CheckpointResourceResp
from huaweicloudsdkcbr.v1.model.copy_backup_request import CopyBackupRequest
from huaweicloudsdkcbr.v1.model.copy_backup_response import CopyBackupResponse
from huaweicloudsdkcbr.v1.model.copy_checkpoint_request import CopyCheckpointRequest
from huaweicloudsdkcbr.v1.model.copy_checkpoint_response import CopyCheckpointResponse
from huaweicloudsdkcbr.v1.model.create_checkpoint_request import CreateCheckpointRequest
from huaweicloudsdkcbr.v1.model.create_checkpoint_response import CreateCheckpointResponse
from huaweicloudsdkcbr.v1.model.create_policy_request import CreatePolicyRequest
from huaweicloudsdkcbr.v1.model.create_policy_response import CreatePolicyResponse
from huaweicloudsdkcbr.v1.model.create_vault_request import CreateVaultRequest
from huaweicloudsdkcbr.v1.model.create_vault_response import CreateVaultResponse
from huaweicloudsdkcbr.v1.model.create_vault_tags_request import CreateVaultTagsRequest
from huaweicloudsdkcbr.v1.model.create_vault_tags_response import CreateVaultTagsResponse
from huaweicloudsdkcbr.v1.model.delete_backup_request import DeleteBackupRequest
from huaweicloudsdkcbr.v1.model.delete_backup_response import DeleteBackupResponse
from huaweicloudsdkcbr.v1.model.delete_member_request import DeleteMemberRequest
from huaweicloudsdkcbr.v1.model.delete_member_response import DeleteMemberResponse
from huaweicloudsdkcbr.v1.model.delete_policy_request import DeletePolicyRequest
from huaweicloudsdkcbr.v1.model.delete_policy_response import DeletePolicyResponse
from huaweicloudsdkcbr.v1.model.delete_vault_request import DeleteVaultRequest
from huaweicloudsdkcbr.v1.model.delete_vault_response import DeleteVaultResponse
from huaweicloudsdkcbr.v1.model.delete_vault_tag_request import DeleteVaultTagRequest
from huaweicloudsdkcbr.v1.model.delete_vault_tag_response import DeleteVaultTagResponse
from huaweicloudsdkcbr.v1.model.disassociate_vault_policy_request import DisassociateVaultPolicyRequest
from huaweicloudsdkcbr.v1.model.disassociate_vault_policy_response import DisassociateVaultPolicyResponse
from huaweicloudsdkcbr.v1.model.image_data import ImageData
from huaweicloudsdkcbr.v1.model.import_backup_request import ImportBackupRequest
from huaweicloudsdkcbr.v1.model.import_backup_response import ImportBackupResponse
from huaweicloudsdkcbr.v1.model.list_backups_request import ListBackupsRequest
from huaweicloudsdkcbr.v1.model.list_backups_response import ListBackupsResponse
from huaweicloudsdkcbr.v1.model.list_op_logs_request import ListOpLogsRequest
from huaweicloudsdkcbr.v1.model.list_op_logs_response import ListOpLogsResponse
from huaweicloudsdkcbr.v1.model.list_policies_request import ListPoliciesRequest
from huaweicloudsdkcbr.v1.model.list_policies_response import ListPoliciesResponse
from huaweicloudsdkcbr.v1.model.list_protectable_request import ListProtectableRequest
from huaweicloudsdkcbr.v1.model.list_protectable_response import ListProtectableResponse
from huaweicloudsdkcbr.v1.model.list_vault_request import ListVaultRequest
from huaweicloudsdkcbr.v1.model.list_vault_response import ListVaultResponse
from huaweicloudsdkcbr.v1.model.match import Match
from huaweicloudsdkcbr.v1.model.member import Member
from huaweicloudsdkcbr.v1.model.migrate_vault_resource_request import MigrateVaultResourceRequest
from huaweicloudsdkcbr.v1.model.migrate_vault_resource_response import MigrateVaultResourceResponse
from huaweicloudsdkcbr.v1.model.op_error_info import OpErrorInfo
from huaweicloudsdkcbr.v1.model.op_extend_info_bckup import OpExtendInfoBckup
from huaweicloudsdkcbr.v1.model.op_extend_info_common import OpExtendInfoCommon
from huaweicloudsdkcbr.v1.model.op_extend_info_delete import OpExtendInfoDelete
from huaweicloudsdkcbr.v1.model.op_extend_info_remove_resources import OpExtendInfoRemoveResources
from huaweicloudsdkcbr.v1.model.op_extend_info_replication import OpExtendInfoReplication
from huaweicloudsdkcbr.v1.model.op_extend_info_restore import OpExtendInfoRestore
from huaweicloudsdkcbr.v1.model.op_extend_info_sync import OpExtendInfoSync
from huaweicloudsdkcbr.v1.model.op_extend_info_vault_delete import OpExtendInfoVaultDelete
from huaweicloudsdkcbr.v1.model.op_extra_info import OpExtraInfo
from huaweicloudsdkcbr.v1.model.operation_log import OperationLog
from huaweicloudsdkcbr.v1.model.policy import Policy
from huaweicloudsdkcbr.v1.model.policy_associate_vault import PolicyAssociateVault
from huaweicloudsdkcbr.v1.model.policy_create import PolicyCreate
from huaweicloudsdkcbr.v1.model.policy_create_req import PolicyCreateReq
from huaweicloudsdkcbr.v1.model.policy_trigger_properties_req import PolicyTriggerPropertiesReq
from huaweicloudsdkcbr.v1.model.policy_trigger_properties_resp import PolicyTriggerPropertiesResp
from huaweicloudsdkcbr.v1.model.policy_trigger_req import PolicyTriggerReq
from huaweicloudsdkcbr.v1.model.policy_trigger_resp import PolicyTriggerResp
from huaweicloudsdkcbr.v1.model.policy_update import PolicyUpdate
from huaweicloudsdkcbr.v1.model.policy_update_req import PolicyUpdateReq
from huaweicloudsdkcbr.v1.model.policyo_od_create import PolicyoODCreate
from huaweicloudsdkcbr.v1.model.protectable_replication_capabilities_resp_region import ProtectableReplicationCapabilitiesRespRegion
from huaweicloudsdkcbr.v1.model.protectable_result import ProtectableResult
from huaweicloudsdkcbr.v1.model.protectables_resp import ProtectablesResp
from huaweicloudsdkcbr.v1.model.remove_vault_resource_request import RemoveVaultResourceRequest
from huaweicloudsdkcbr.v1.model.remove_vault_resource_response import RemoveVaultResourceResponse
from huaweicloudsdkcbr.v1.model.replication_record_get import ReplicationRecordGet
from huaweicloudsdkcbr.v1.model.replication_records_extra_info import ReplicationRecordsExtraInfo
from huaweicloudsdkcbr.v1.model.resource import Resource
from huaweicloudsdkcbr.v1.model.resource_create import ResourceCreate
from huaweicloudsdkcbr.v1.model.resource_extra_info import ResourceExtraInfo
from huaweicloudsdkcbr.v1.model.resource_extra_info_include_volumes import ResourceExtraInfoIncludeVolumes
from huaweicloudsdkcbr.v1.model.resource_resp import ResourceResp
from huaweicloudsdkcbr.v1.model.restore_backup_request import RestoreBackupRequest
from huaweicloudsdkcbr.v1.model.restore_backup_response import RestoreBackupResponse
from huaweicloudsdkcbr.v1.model.show_backup_request import ShowBackupRequest
from huaweicloudsdkcbr.v1.model.show_backup_response import ShowBackupResponse
from huaweicloudsdkcbr.v1.model.show_checkpoint_request import ShowCheckpointRequest
from huaweicloudsdkcbr.v1.model.show_checkpoint_response import ShowCheckpointResponse
from huaweicloudsdkcbr.v1.model.show_member_detail_request import ShowMemberDetailRequest
from huaweicloudsdkcbr.v1.model.show_member_detail_response import ShowMemberDetailResponse
from huaweicloudsdkcbr.v1.model.show_members_detail_request import ShowMembersDetailRequest
from huaweicloudsdkcbr.v1.model.show_members_detail_response import ShowMembersDetailResponse
from huaweicloudsdkcbr.v1.model.show_op_log_request import ShowOpLogRequest
from huaweicloudsdkcbr.v1.model.show_op_log_response import ShowOpLogResponse
from huaweicloudsdkcbr.v1.model.show_policy_request import ShowPolicyRequest
from huaweicloudsdkcbr.v1.model.show_policy_response import ShowPolicyResponse
from huaweicloudsdkcbr.v1.model.show_protectable_request import ShowProtectableRequest
from huaweicloudsdkcbr.v1.model.show_protectable_response import ShowProtectableResponse
from huaweicloudsdkcbr.v1.model.show_replication_capabilities_request import ShowReplicationCapabilitiesRequest
from huaweicloudsdkcbr.v1.model.show_replication_capabilities_response import ShowReplicationCapabilitiesResponse
from huaweicloudsdkcbr.v1.model.show_vault_project_tag_request import ShowVaultProjectTagRequest
from huaweicloudsdkcbr.v1.model.show_vault_project_tag_response import ShowVaultProjectTagResponse
from huaweicloudsdkcbr.v1.model.show_vault_request import ShowVaultRequest
from huaweicloudsdkcbr.v1.model.show_vault_resource_instances_request import ShowVaultResourceInstancesRequest
from huaweicloudsdkcbr.v1.model.show_vault_resource_instances_response import ShowVaultResourceInstancesResponse
from huaweicloudsdkcbr.v1.model.show_vault_response import ShowVaultResponse
from huaweicloudsdkcbr.v1.model.show_vault_tag_request import ShowVaultTagRequest
from huaweicloudsdkcbr.v1.model.show_vault_tag_response import ShowVaultTagResponse
from huaweicloudsdkcbr.v1.model.sys_tag import SysTag
from huaweicloudsdkcbr.v1.model.sys_tags import SysTags
from huaweicloudsdkcbr.v1.model.tag import Tag
from huaweicloudsdkcbr.v1.model.tag_resource import TagResource
from huaweicloudsdkcbr.v1.model.tags_req import TagsReq
from huaweicloudsdkcbr.v1.model.tags_resp import TagsResp
from huaweicloudsdkcbr.v1.model.update_member import UpdateMember
from huaweicloudsdkcbr.v1.model.update_member_status_request import UpdateMemberStatusRequest
from huaweicloudsdkcbr.v1.model.update_member_status_response import UpdateMemberStatusResponse
from huaweicloudsdkcbr.v1.model.update_policy_request import UpdatePolicyRequest
from huaweicloudsdkcbr.v1.model.update_policy_response import UpdatePolicyResponse
from huaweicloudsdkcbr.v1.model.update_vault_request import UpdateVaultRequest
from huaweicloudsdkcbr.v1.model.update_vault_response import UpdateVaultResponse
from huaweicloudsdkcbr.v1.model.vault import Vault
from huaweicloudsdkcbr.v1.model.vault_add_resource_req import VaultAddResourceReq
from huaweicloudsdkcbr.v1.model.vault_associate import VaultAssociate
from huaweicloudsdkcbr.v1.model.vault_backup import VaultBackup
from huaweicloudsdkcbr.v1.model.vault_backup_req import VaultBackupReq
from huaweicloudsdkcbr.v1.model.vault_bind_rules import VaultBindRules
from huaweicloudsdkcbr.v1.model.vault_create import VaultCreate
from huaweicloudsdkcbr.v1.model.vault_create_req import VaultCreateReq
from huaweicloudsdkcbr.v1.model.vault_create_resource import VaultCreateResource
from huaweicloudsdkcbr.v1.model.vault_dissociate import VaultDissociate
from huaweicloudsdkcbr.v1.model.vault_get import VaultGet
from huaweicloudsdkcbr.v1.model.vault_migrate_resource_req import VaultMigrateResourceReq
from huaweicloudsdkcbr.v1.model.vault_policy_resp import VaultPolicyResp
from huaweicloudsdkcbr.v1.model.vault_remove_resource_req import VaultRemoveResourceReq
from huaweicloudsdkcbr.v1.model.vault_resource_instances_req import VaultResourceInstancesReq
from huaweicloudsdkcbr.v1.model.vault_tags_create_req import VaultTagsCreateReq
from huaweicloudsdkcbr.v1.model.vault_update import VaultUpdate
from huaweicloudsdkcbr.v1.model.vault_update_req import VaultUpdateReq

==> huaweicloudsdkcbr-3.1.39-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import models into model package
from huaweicloudsdkcbr.v1.model.add_member_request import AddMemberRequest
from huaweicloudsdkcbr.v1.model.add_member_response import AddMemberResponse
from huaweicloudsdkcbr.v1.model.add_members_req import AddMembersReq
from huaweicloudsdkcbr.v1.model.add_vault_resource_request import AddVaultResourceRequest
from huaweicloudsdkcbr.v1.model.add_vault_resource_response import AddVaultResourceResponse
from huaweicloudsdkcbr.v1.model.associate_vault_policy_request import AssociateVaultPolicyRequest
from huaweicloudsdkcbr.v1.model.associate_vault_policy_response import AssociateVaultPolicyResponse
from huaweicloudsdkcbr.v1.model.backup_extend_info import BackupExtendInfo
from huaweicloudsdkcbr.v1.model.backup_replicate_req import BackupReplicateReq
from huaweicloudsdkcbr.v1.model.backup_replicate_req_body import BackupReplicateReqBody
from huaweicloudsdkcbr.v1.model.backup_replicate_resp_body import BackupReplicateRespBody
from huaweicloudsdkcbr.v1.model.backup_resp import BackupResp
from huaweicloudsdkcbr.v1.model.backup_restore import BackupRestore
from huaweicloudsdkcbr.v1.model.backup_restore_req import BackupRestoreReq
from huaweicloudsdkcbr.v1.model.backup_restore_server_mapping import BackupRestoreServerMapping
from huaweicloudsdkcbr.v1.model.backup_sync import BackupSync
from huaweicloudsdkcbr.v1.model.backup_sync_req import BackupSyncReq
from huaweicloudsdkcbr.v1.model.backup_sync_resp_body import BackupSyncRespBody
from huaweicloudsdkcbr.v1.model.batch_create_and_delete_vault_tags_request import BatchCreateAndDeleteVaultTagsRequest
from huaweicloudsdkcbr.v1.model.batch_create_and_delete_vault_tags_response import BatchCreateAndDeleteVaultTagsResponse
from huaweicloudsdkcbr.v1.model.billing import Billing
from huaweicloudsdkcbr.v1.model.billing_create import BillingCreate
from huaweicloudsdkcbr.v1.model.billing_update import BillingUpdate
from huaweicloudsdkcbr.v1.model.bind_rules_tags import BindRulesTags
from huaweicloudsdkcbr.v1.model.bulk_create_and_delete_vault_tags_req import BulkCreateAndDeleteVaultTagsReq
from huaweicloudsdkcbr.v1.model.cbc_order_result import CbcOrderResult
from huaweicloudsdkcbr.v1.model.checkpoint_create import CheckpointCreate
from huaweicloudsdkcbr.v1.model.checkpoint_create_skipped_resource import CheckpointCreateSkippedResource
from huaweicloudsdkcbr.v1.model.checkpoint_extra_info_resp import CheckpointExtraInfoResp
from huaweicloudsdkcbr.v1.model.checkpoint_param import CheckpointParam
from huaweicloudsdkcbr.v1.model.checkpoint_plan_create import CheckpointPlanCreate
from huaweicloudsdkcbr.v1.model.checkpoint_replicate_param import CheckpointReplicateParam
from huaweicloudsdkcbr.v1.model.checkpoint_replicate_req import CheckpointReplicateReq
from huaweicloudsdkcbr.v1.model.checkpoint_replicate_resp_body import CheckpointReplicateRespBody
from huaweicloudsdkcbr.v1.model.checkpoint_replicate_respbackups import CheckpointReplicateRespbackups
from huaweicloudsdkcbr.v1.model.checkpoint_resource_resp import CheckpointResourceResp
from huaweicloudsdkcbr.v1.model.copy_backup_request import CopyBackupRequest
from huaweicloudsdkcbr.v1.model.copy_backup_response import CopyBackupResponse
from huaweicloudsdkcbr.v1.model.copy_checkpoint_request import CopyCheckpointRequest
from huaweicloudsdkcbr.v1.model.copy_checkpoint_response import CopyCheckpointResponse
from huaweicloudsdkcbr.v1.model.create_checkpoint_request import CreateCheckpointRequest
from huaweicloudsdkcbr.v1.model.create_checkpoint_response import CreateCheckpointResponse
from huaweicloudsdkcbr.v1.model.create_policy_request import CreatePolicyRequest
from huaweicloudsdkcbr.v1.model.create_policy_response import CreatePolicyResponse
from huaweicloudsdkcbr.v1.model.create_vault_request import CreateVaultRequest
from huaweicloudsdkcbr.v1.model.create_vault_response import CreateVaultResponse
from huaweicloudsdkcbr.v1.model.create_vault_tags_request import CreateVaultTagsRequest
from huaweicloudsdkcbr.v1.model.create_vault_tags_response import CreateVaultTagsResponse
from huaweicloudsdkcbr.v1.model.delete_backup_request import DeleteBackupRequest
from huaweicloudsdkcbr.v1.model.delete_backup_response import DeleteBackupResponse
from huaweicloudsdkcbr.v1.model.delete_member_request import DeleteMemberRequest
from huaweicloudsdkcbr.v1.model.delete_member_response import DeleteMemberResponse
from huaweicloudsdkcbr.v1.model.delete_policy_request import DeletePolicyRequest
from huaweicloudsdkcbr.v1.model.delete_policy_response import DeletePolicyResponse
from huaweicloudsdkcbr.v1.model.delete_vault_request import DeleteVaultRequest
from huaweicloudsdkcbr.v1.model.delete_vault_response import DeleteVaultResponse
from huaweicloudsdkcbr.v1.model.delete_vault_tag_request import DeleteVaultTagRequest
from huaweicloudsdkcbr.v1.model.delete_vault_tag_response import DeleteVaultTagResponse
from huaweicloudsdkcbr.v1.model.disassociate_vault_policy_request import DisassociateVaultPolicyRequest
from huaweicloudsdkcbr.v1.model.disassociate_vault_policy_response import DisassociateVaultPolicyResponse
from huaweicloudsdkcbr.v1.model.image_data import ImageData
from huaweicloudsdkcbr.v1.model.import_backup_request import ImportBackupRequest
from huaweicloudsdkcbr.v1.model.import_backup_response import ImportBackupResponse
from huaweicloudsdkcbr.v1.model.instances_resource_detail import InstancesResourceDetail
from huaweicloudsdkcbr.v1.model.list_backups_request import ListBackupsRequest
from huaweicloudsdkcbr.v1.model.list_backups_response import ListBackupsResponse
from huaweicloudsdkcbr.v1.model.list_op_logs_request import ListOpLogsRequest
from huaweicloudsdkcbr.v1.model.list_op_logs_response import ListOpLogsResponse
from huaweicloudsdkcbr.v1.model.list_policies_request import ListPoliciesRequest
from huaweicloudsdkcbr.v1.model.list_policies_response import ListPoliciesResponse
from huaweicloudsdkcbr.v1.model.list_protectable_request import ListProtectableRequest
from huaweicloudsdkcbr.v1.model.list_protectable_response import ListProtectableResponse
from huaweicloudsdkcbr.v1.model.list_vault_request import ListVaultRequest
from huaweicloudsdkcbr.v1.model.list_vault_response import ListVaultResponse
from huaweicloudsdkcbr.v1.model.match import Match
from huaweicloudsdkcbr.v1.model.member import Member
from huaweicloudsdkcbr.v1.model.migrate_vault_resource_request import MigrateVaultResourceRequest
from huaweicloudsdkcbr.v1.model.migrate_vault_resource_response import MigrateVaultResourceResponse
from huaweicloudsdkcbr.v1.model.op_error_info import OpErrorInfo
from huaweicloudsdkcbr.v1.model.op_extend_info_bckup import OpExtendInfoBckup
from huaweicloudsdkcbr.v1.model.op_extend_info_common import OpExtendInfoCommon
from huaweicloudsdkcbr.v1.model.op_extend_info_delete import OpExtendInfoDelete
from huaweicloudsdkcbr.v1.model.op_extend_info_remove_resources import OpExtendInfoRemoveResources
from huaweicloudsdkcbr.v1.model.op_extend_info_replication import OpExtendInfoReplication
from huaweicloudsdkcbr.v1.model.op_extend_info_restore import OpExtendInfoRestore
from huaweicloudsdkcbr.v1.model.op_extend_info_sync import OpExtendInfoSync
from huaweicloudsdkcbr.v1.model.op_extend_info_vault_delete import OpExtendInfoVaultDelete
from huaweicloudsdkcbr.v1.model.op_extra_info import OpExtraInfo
from huaweicloudsdkcbr.v1.model.operation_log import OperationLog
from huaweicloudsdkcbr.v1.model.policy import Policy
from huaweicloudsdkcbr.v1.model.policy_associate_vault import PolicyAssociateVault
from huaweicloudsdkcbr.v1.model.policy_create import PolicyCreate
from huaweicloudsdkcbr.v1.model.policy_create_req import PolicyCreateReq
from huaweicloudsdkcbr.v1.model.policy_trigger_properties_req import PolicyTriggerPropertiesReq
from huaweicloudsdkcbr.v1.model.policy_trigger_properties_resp import PolicyTriggerPropertiesResp
from huaweicloudsdkcbr.v1.model.policy_trigger_req import PolicyTriggerReq
from huaweicloudsdkcbr.v1.model.policy_trigger_resp import PolicyTriggerResp
from huaweicloudsdkcbr.v1.model.policy_update import PolicyUpdate
from huaweicloudsdkcbr.v1.model.policy_update_req import PolicyUpdateReq
from huaweicloudsdkcbr.v1.model.policyo_od_create import PolicyoODCreate
from huaweicloudsdkcbr.v1.model.protectable_replication_capabilities_resp_region import ProtectableReplicationCapabilitiesRespRegion
from huaweicloudsdkcbr.v1.model.protectable_result import ProtectableResult
from huaweicloudsdkcbr.v1.model.protectables_resp import ProtectablesResp
from huaweicloudsdkcbr.v1.model.remove_vault_resource_request import RemoveVaultResourceRequest
from huaweicloudsdkcbr.v1.model.remove_vault_resource_response import RemoveVaultResourceResponse
from huaweicloudsdkcbr.v1.model.replication_record_get import ReplicationRecordGet
from huaweicloudsdkcbr.v1.model.replication_records_extra_info import ReplicationRecordsExtraInfo
from huaweicloudsdkcbr.v1.model.resource import Resource
from huaweicloudsdkcbr.v1.model.resource_create import ResourceCreate
from huaweicloudsdkcbr.v1.model.resource_extra_info import ResourceExtraInfo
from huaweicloudsdkcbr.v1.model.resource_extra_info_include_volumes import ResourceExtraInfoIncludeVolumes
from huaweicloudsdkcbr.v1.model.resource_resp import ResourceResp
from huaweicloudsdkcbr.v1.model.restore_backup_request import RestoreBackupRequest
from huaweicloudsdkcbr.v1.model.restore_backup_response import RestoreBackupResponse
from huaweicloudsdkcbr.v1.model.show_backup_request import ShowBackupRequest
from huaweicloudsdkcbr.v1.model.show_backup_response import ShowBackupResponse
from huaweicloudsdkcbr.v1.model.show_checkpoint_request import ShowCheckpointRequest
from huaweicloudsdkcbr.v1.model.show_checkpoint_response import ShowCheckpointResponse
from huaweicloudsdkcbr.v1.model.show_member_detail_request import ShowMemberDetailRequest
from huaweicloudsdkcbr.v1.model.show_member_detail_response import ShowMemberDetailResponse
from huaweicloudsdkcbr.v1.model.show_members_detail_request import ShowMembersDetailRequest
from huaweicloudsdkcbr.v1.model.show_members_detail_response import ShowMembersDetailResponse
from huaweicloudsdkcbr.v1.model.show_op_log_request import ShowOpLogRequest
from huaweicloudsdkcbr.v1.model.show_op_log_response import ShowOpLogResponse
from huaweicloudsdkcbr.v1.model.show_policy_request import ShowPolicyRequest
from huaweicloudsdkcbr.v1.model.show_policy_response import ShowPolicyResponse
from huaweicloudsdkcbr.v1.model.show_protectable_request import ShowProtectableRequest
from huaweicloudsdkcbr.v1.model.show_protectable_response import ShowProtectableResponse
from huaweicloudsdkcbr.v1.model.show_replication_capabilities_request import ShowReplicationCapabilitiesRequest
from huaweicloudsdkcbr.v1.model.show_replication_capabilities_response import ShowReplicationCapabilitiesResponse
from huaweicloudsdkcbr.v1.model.show_vault_project_tag_request import ShowVaultProjectTagRequest
from huaweicloudsdkcbr.v1.model.show_vault_project_tag_response import ShowVaultProjectTagResponse
from huaweicloudsdkcbr.v1.model.show_vault_request import ShowVaultRequest
from huaweicloudsdkcbr.v1.model.show_vault_resource_instances_request import ShowVaultResourceInstancesRequest
from huaweicloudsdkcbr.v1.model.show_vault_resource_instances_response import ShowVaultResourceInstancesResponse
from huaweicloudsdkcbr.v1.model.show_vault_response import ShowVaultResponse
from huaweicloudsdkcbr.v1.model.show_vault_tag_request import ShowVaultTagRequest
from huaweicloudsdkcbr.v1.model.show_vault_tag_response import ShowVaultTagResponse
from huaweicloudsdkcbr.v1.model.sys_tag import SysTag
from huaweicloudsdkcbr.v1.model.sys_tags import SysTags
from huaweicloudsdkcbr.v1.model.tag import Tag
from huaweicloudsdkcbr.v1.model.tag_resource import TagResource
from huaweicloudsdkcbr.v1.model.tags_req import TagsReq
from huaweicloudsdkcbr.v1.model.tags_resp import TagsResp
from huaweicloudsdkcbr.v1.model.update_member import UpdateMember
from huaweicloudsdkcbr.v1.model.update_member_status_request import UpdateMemberStatusRequest
from huaweicloudsdkcbr.v1.model.update_member_status_response import UpdateMemberStatusResponse
from huaweicloudsdkcbr.v1.model.update_policy_request import UpdatePolicyRequest
from huaweicloudsdkcbr.v1.model.update_policy_response import UpdatePolicyResponse
from huaweicloudsdkcbr.v1.model.update_vault_request import UpdateVaultRequest
from huaweicloudsdkcbr.v1.model.update_vault_response import UpdateVaultResponse
from huaweicloudsdkcbr.v1.model.vault import Vault
from huaweicloudsdkcbr.v1.model.vault_add_resource_req import VaultAddResourceReq
from huaweicloudsdkcbr.v1.model.vault_associate import VaultAssociate
from huaweicloudsdkcbr.v1.model.vault_backup import VaultBackup
from huaweicloudsdkcbr.v1.model.vault_backup_req import VaultBackupReq
from huaweicloudsdkcbr.v1.model.vault_bind_rules import VaultBindRules
from huaweicloudsdkcbr.v1.model.vault_create import VaultCreate
from huaweicloudsdkcbr.v1.model.vault_create_req import VaultCreateReq
from huaweicloudsdkcbr.v1.model.vault_create_resource import VaultCreateResource
from huaweicloudsdkcbr.v1.model.vault_dissociate import VaultDissociate
from huaweicloudsdkcbr.v1.model.vault_get import VaultGet
from huaweicloudsdkcbr.v1.model.vault_migrate_resource_req import VaultMigrateResourceReq
from huaweicloudsdkcbr.v1.model.vault_policy_resp import VaultPolicyResp
from huaweicloudsdkcbr.v1.model.vault_remove_resource_req import VaultRemoveResourceReq
from huaweicloudsdkcbr.v1.model.vault_resource_instances_req import VaultResourceInstancesReq
from huaweicloudsdkcbr.v1.model.vault_tags_create_req import VaultTagsCreateReq
from huaweicloudsdkcbr.v1.model.vault_update import VaultUpdate
from huaweicloudsdkcbr.v1.model.vault_update_req import VaultUpdateReq
